summaryrefslogtreecommitdiffstats
path: root/kspread/dialogs/kspread_dlg_layout.cc
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /kspread/dialogs/kspread_dlg_layout.cc
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kspread/dialogs/kspread_dlg_layout.cc')
-rw-r--r--kspread/dialogs/kspread_dlg_layout.cc46
1 files changed, 23 insertions, 23 deletions
diff --git a/kspread/dialogs/kspread_dlg_layout.cc b/kspread/dialogs/kspread_dlg_layout.cc
index 8c21d75a..53942457 100644
--- a/kspread/dialogs/kspread_dlg_layout.cc
+++ b/kspread/dialogs/kspread_dlg_layout.cc
@@ -73,8 +73,8 @@ using namespace KSpread;
*
***************************************************************************/
-PatternSelect::PatternSelect( TQWidget *tqparent, const char * )
- : TQFrame( tqparent )
+PatternSelect::PatternSelect( TQWidget *parent, const char * )
+ : TQFrame( parent )
{
penStyle = Qt::NoPen;
penWidth = 1;
@@ -147,8 +147,8 @@ void PatternSelect::slotSelect()
*
***************************************************************************/
-GeneralTab::GeneralTab( TQWidget* tqparent, CellFormatDialog * dlg )
- : TQWidget( tqparent ),
+GeneralTab::GeneralTab( TQWidget* parent, CellFormatDialog * dlg )
+ : TQWidget( parent ),
m_dlg( dlg )
{
TQGridLayout * tqlayout = new TQGridLayout( this, 1, 1, KDialog::marginHint(), KDialog::spacingHint(), "tqlayout");
@@ -181,7 +181,7 @@ GeneralTab::GeneralTab( TQWidget* tqparent, CellFormatDialog * dlg )
tmp.remove( m_dlg->styleName );
m_parentBox->insertStringList( tmp );
- if ( m_dlg->getStyle()->tqparent() )
+ if ( m_dlg->getStyle()->parent() )
m_parentBox->setCurrentText( m_dlg->getStyle()->parentName() );
else
{
@@ -230,7 +230,7 @@ void GeneralTab::slotNewParent( const TQString & parentName )
else
m_dlg->getStyle()->setParent( m_dlg->getStyleManager()->style( parentName ) );
// Set difference to new tqparent, set GUI to tqparent values, add changes made before
// m_dlg->initGUI();
}
@@ -270,7 +270,7 @@ bool GeneralTab::checkParent( const TQString & parentName )
if ( !p )
{
- KMessageBox::sorry( this, i18n( "The tqparent style does not exist." ) );
+ KMessageBox::sorry( this, i18n( "The parent style does not exist." ) );
return false;
}
}
@@ -766,9 +766,9 @@ void CellFormatDialog::initMembers()
defaultHeightSize = sheet ? sheet->rowFormat(0)->dblHeight() : 0;
}
-bool CellFormatDialog::checkCircle( TQString const & name, TQString const & tqparent )
+bool CellFormatDialog::checkCircle( TQString const & name, TQString const & parent )
{
- return m_styleManager->checkCircle( name, tqparent );
+ return m_styleManager->checkCircle( name, parent );
}
void CellFormatDialog::checkBorderRight(Format *obj,int x,int y)
@@ -1078,8 +1078,8 @@ void CellFormatDialog::slotApply()
*
***************************************************************************/
-CellFormatPageFloat::CellFormatPageFloat( TQWidget* tqparent, CellFormatDialog *_dlg )
- : TQWidget ( tqparent ),
+CellFormatPageFloat::CellFormatPageFloat( TQWidget* parent, CellFormatDialog *_dlg )
+ : TQWidget ( parent ),
dlg( _dlg )
{
TQVBoxLayout* tqlayout = new TQVBoxLayout( this, 6,10 );
@@ -1881,8 +1881,8 @@ void CellFormatPageFloat::apply(FormatManipulator* _obj)
*
***************************************************************************/
-CellFormatPageProtection::CellFormatPageProtection( TQWidget* tqparent, CellFormatDialog * _dlg )
- : ProtectionTab( tqparent ),
+CellFormatPageProtection::CellFormatPageProtection( TQWidget* parent, CellFormatDialog * _dlg )
+ : ProtectionTab( parent ),
m_dlg( _dlg )
{
m_bDontPrint->setChecked( m_dlg->bDontPrintText );
@@ -1953,7 +1953,7 @@ void CellFormatPageProtection::apply(FormatManipulator* _obj)
*
***************************************************************************/
-CellFormatPageFont::CellFormatPageFont( TQWidget* tqparent, CellFormatDialog *_dlg ) : FontTab( tqparent )
+CellFormatPageFont::CellFormatPageFont( TQWidget* parent, CellFormatDialog *_dlg ) : FontTab( parent )
{
dlg = _dlg;
@@ -2228,8 +2228,8 @@ void CellFormatPageFont::setCombos()
*
***************************************************************************/
-CellFormatPagePosition::CellFormatPagePosition( TQWidget* tqparent, CellFormatDialog *_dlg )
- : PositionTab(tqparent ),
+CellFormatPagePosition::CellFormatPagePosition( TQWidget* parent, CellFormatDialog *_dlg )
+ : PositionTab(parent ),
dlg( _dlg )
{
if ( dlg->alignX == Format::Left )
@@ -2529,7 +2529,7 @@ double CellFormatPagePosition::getSizeWidth() const
*
***************************************************************************/
-BorderButton::BorderButton( TQWidget *tqparent, const char *_name ) : TQPushButton(tqparent,_name)
+BorderButton::BorderButton( TQWidget *parent, const char *_name ) : TQPushButton(parent,_name)
{
penStyle = Qt::NoPen;
penWidth = 1;
@@ -2570,8 +2570,8 @@ void BorderButton::unselect()
*
***************************************************************************/
-Border::Border( TQWidget *tqparent, const char *_name,bool _oneCol, bool _oneRow )
- : TQFrame( tqparent, _name )
+Border::Border( TQWidget *parent, const char *_name,bool _oneCol, bool _oneRow )
+ : TQFrame( parent, _name )
{
oneCol=_oneCol;
oneRow=_oneRow;
@@ -2630,8 +2630,8 @@ void Border::mousePressEvent( TQMouseEvent* _ev )
*
***************************************************************************/
-CellFormatPageBorder::CellFormatPageBorder( TQWidget* tqparent, CellFormatDialog *_dlg )
- : TQWidget( tqparent ),
+CellFormatPageBorder::CellFormatPageBorder( TQWidget* parent, CellFormatDialog *_dlg )
+ : TQWidget( parent ),
dlg( _dlg )
{
sheet = dlg->getSheet();
@@ -3494,7 +3494,7 @@ if (rect.contains(TQPoint(_ev->x(),_ev->y())))
*
***************************************************************************/
-BrushSelect::BrushSelect( TQWidget *tqparent, const char * ) : TQFrame( tqparent )
+BrushSelect::BrushSelect( TQWidget *parent, const char * ) : TQFrame( parent )
{
brushStyle = Qt::NoBrush;
brushColor = TQt::red;
@@ -3555,7 +3555,7 @@ void BrushSelect::slotSelect()
*
***************************************************************************/
-CellFormatPagePattern::CellFormatPagePattern( TQWidget* tqparent, CellFormatDialog *_dlg ) : TQWidget( tqparent )
+CellFormatPagePattern::CellFormatPagePattern( TQWidget* parent, CellFormatDialog *_dlg ) : TQWidget( parent )
{
dlg = _dlg;
@@ -230,7 +230,7 @@ void GeneralTab::slotNewParent( const TQString & parentName )
else
m_dlg->getStyle()->setParent( m_dlg->getStyleManager()->style( parentName ) );
- // Set difference to new tqparent, set GUI to tqparent values, add changes made before
+ // Set difference to new parent, set GUI to parent values, add changes made before
// m_dlg->initGUI();
}